@@ -2273,7 +2273,6 @@ void strokepath(XPoint *pathlist, short number, short style, float width)
    char         dashstring[3];
    float        tmpwidth;
    short	minwidth;
-   static Pixmap pbuf = (Pixmap)NULL;
 
    tmpwidth = UTopTransScale(width);
    minwidth = max(1, (short)tmpwidth);
@@ -2336,11 +2335,11 @@ void strokepath(XPoint *pathlist, short number, short style, float width)
          areawin->clipped++;
       }
       else if ((areawin->clipped > 0) && (areawin->clipped & 1) == 0) {
-	 if (pbuf == (Pixmap)NULL) {
-	    pbuf = XCreatePixmap (dpy, areawin->window, areawin->width,
-			areawin->height, 1);
+	 if (areawin->pbuf == (Pixmap)NULL) {
+	    areawin->pbuf = XCreatePixmap (dpy, areawin->window,
+			areawin->width, areawin->height, 1);
 	 }
-	 XCopyArea(dpy, areawin->clipmask, pbuf, areawin->cmgc,
+	 XCopyArea(dpy, areawin->clipmask, areawin->pbuf, areawin->cmgc,
 		0, 0, areawin->width, areawin->height, 0, 0);
          XSetForeground(dpy, areawin->cmgc, 0);
          XFillRectangle(dpy, areawin->clipmask, areawin->cmgc, 0, 0,
@@ -2349,7 +2348,7 @@ void strokepath(XPoint *pathlist, short number, short style, float width)
          FillPolygon(dpy, areawin->clipmask, areawin->cmgc, pathlist,
 		number, Nonconvex, CoordModeOrigin);
          XSetFunction(dpy, areawin->cmgc, GXand);
-	 XCopyArea(dpy, pbuf, areawin->clipmask, areawin->cmgc,
+	 XCopyArea(dpy, areawin->pbuf, areawin->clipmask, areawin->cmgc,
 		0, 0, areawin->width, areawin->height, 0, 0);
          XSetFunction(dpy, areawin->cmgc, GXcopy);
          XSetClipMask(dpy, areawin->gc, areawin->clipmask);
